Method: Command::Argument#complete
- Defined in:
- lib/command-set/arguments.rb
#complete(prefix, subject) ⇒ Object
Provides a list of completion options based on a string prefix and the subject The completion should be an array of completion options. If the completions have a common prefix, completion will enter it for the user. As a clever trick for providing hints:
[ "This is a hint", "" ]
25 26 27 |
# File 'lib/command-set/arguments.rb', line 25 def complete(prefix, subject) raise NotImplementedError, "complete not implemented in #{self.class.name}" end |