Method: Command::Argument#validate
- Defined in:
- lib/command-set/arguments.rb
#validate(term, subject) ⇒ Object
Validates the input string against the type of the argument. Returns true if the input is valid, or else false
48 49 50 |
# File 'lib/command-set/arguments.rb', line 48 def validate(term, subject) raise NotImplementedError, "validate not implemented in #{self.class.name}" end |